@@ -64,10 +64,6 @@ namespace Oxygen
         //! destructor
         virtual ~ShadowHelper( void );
 
-        //! true if supported
-        bool isSupported( void ) const
-        { return _supported; }
-
         //! reset
         void reset( void );
 
@@ -93,9 +89,6 @@ namespace Oxygen
 
         protected:
 
-        //! true if shadows are supported
-        bool checkSupported( void ) const;
-
         //! true if widget is a menu
         bool isMenu( QWidget* ) const;
 
@@ -140,9 +133,6 @@ namespace Oxygen
         //! helper
         StyleHelper& _helper;
 
-        //! true if supported
-        bool _supported;
-
         //! cache
         ShadowCache* _shadowCache;
 
